/*
 * Copyright 2016 frankmuenster.de
 * Lizenziert unter der EUPL, Version 1.1 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 * http://ec.europa.eu/idabc/eupl
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 */

package de.frankmuenster.jameica.depot.finanzen;


/**
 * Exception Klasse f&uuml;r alle Arten von Finanz_API Fehlern.
 * 
 * @author Frank Mnster
 * 
 */
public class FinanceException extends Exception {

	/**
	 * Serial UID
	 */
	private static final long serialVersionUID = 4393264654949338915L;
	
	/**
	 * Der Type des Yahoo Fehlers
	 */
	private final transient FinanceExceptionType type;

	
	
	/**
	 * Konstruktor mit Informationstext und Fehlertyp.
	 * 
	 * @param message
	 *            der Informationstext
	 * @param type
	 *            der Felertyp
	 */
	public FinanceException(final String message,
			final FinanceExceptionType type) {
		this(message, type,null);
	}

	/**
	 * Konstruktor mit Informationstext, Fehlertyp und Ursache.
	 * 
	 * @param message
	 *            der Informationstext
	 * @param type
	 *            der Fehlertyp
	 * @param throwable der original Fehler
	 */
	public FinanceException(final String message,
			final FinanceExceptionType type, final Throwable throwable ) {
		super(message, throwable);
		this.type = type;
	}
	
	/**
	 * Liefert den Fehlertyp der Exception
	 * 
	 * @return der Yahoo-Finanz-API-Fehlertyp
	 */
	public FinanceExceptionType getType() {
		return type;
	}
}
