//
// Copyright 2017 frankmuenster.de
// 
// Lizenziert unter der EUPL, Version 1.1 oder - sobald
// diese von der Europischen Kommission genehmigt wurden -
// Folgeversionen der EUPL ("Lizenz");
// Sie drfen dieses Werk ausschlielich gem
// dieser Lizenz nutzen.
// Eine Kopie der Lizenz finden Sie hier:
// 
//   http://ec.europa.eu/idabc/eupl
// 
// Sofern nicht durch anwendbare Rechtsvorschriften
// gefordert oder in schriftlicher Form vereinbart, wird
// die unter der Lizenz verbreitete Software "so wie sie
// ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
// ausdrcklich oder stillschweigend - verbreitet.
// Die sprachspezifischen Genehmigungen und Beschrnkungen
// unter der Lizenz sind dem Lizenztext zu entnehmen.
// 

package de.frankmuenster.jameica.depot.finanzen.boerseffm.json;

import java.util.List;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;

/**
 * Das Instrument Objekt der FFM (warum auch immer das Instrument heit???
 * 
 * @author Frank Mnster
 * 
 */
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({ "identifier", "hasPreviousDayClose", "hasOHLC", "data" })
public class Instrument {

	/**
	 * Der ID String
	 */
	@JsonProperty("identifier")
	private transient String identifier;
	
	/**
	 * Gibt es den Schlusskurs vom Handelstag davor
	 */
	@JsonProperty("hasPreviousDayClose")
	private transient Boolean hasPreviousDayClose;  //NOPMD
	
	/**
	 * OLHC Werte vorhanden
	 */
	@JsonProperty("hasOHLC")
	private transient Boolean hasOHLC;
	
	/**
	 * Und die Daten
	 */
	@JsonProperty("data")
	@JsonDeserialize(using = DataDeserialiser.class)
	private transient List<ChartData> data;

	
	/**
	 * Standardkonstruktor
	 */
	public Instrument() {
		// Absichtlich leer
	}
	
	/**
	 * Liefert den ID-String
	 * @return den ID-String
	 */
	@JsonProperty("identifier")
	public String getIdentifier() {
		return identifier;
	}

	/**
	 * Liefert <i>true</i>, wenn Schlusskursdaten vom letzten Handelstag vorhanden sind.
	 * @return Schlusskursdaten vorhanden
	 */
	@JsonProperty("hasPreviousDayClose")
	public Boolean getHasPreviousDayClose() {
		return hasPreviousDayClose;
	}

	/**
	 *  Liefert <i>true</i>, wenn OHLC Daten vorhanden sind.
	 * @return OHLC Daten vorhanden
	 */
	@JsonProperty("hasOHLC")
	public Boolean getHasOHLC() {
		return hasOHLC;
	}

	/**
	 * Liste der vorhandenen Daten
	 * @return  Liste der vorhandenen Daten
	 */
	public List<ChartData> getData() {
		return data;
	}

}
