//
// Copyright 2014 frankmuenster.de
// 
// Lizenziert unter der EUPL, Version 1.1 oder - sobald
// diese von der Europischen Kommission genehmigt wurden -
// Folgeversionen der EUPL ("Lizenz");
// Sie drfen dieses Werk ausschlielich gem
// dieser Lizenz nutzen.
// Eine Kopie der Lizenz finden Sie hier:
// 
//   http://ec.europa.eu/idabc/eupl
// 
// Sofern nicht durch anwendbare Rechtsvorschriften
// gefordert oder in schriftlicher Form vereinbart, wird
// die unter der Lizenz verbreitete Software "so wie sie
// ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
// ausdrcklich oder stillschweigend - verbreitet.
// Die sprachspezifischen Genehmigungen und Beschrnkungen
// unter der Lizenz sind dem Lizenztext zu entnehmen.
// 

package de.frankmuenster.jameica.depot.finanzen.boerseffm.json;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;

/**
 * JSON Beschreibung des InstrumentType.
 * 
 * @author Frank Mnster
 *
 */
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({ "InstrumentID", "Name", "Category", "WKN", "ISIN", "Valor", "Symbol", "LocalIdentifier", "Bias",
		"InstrumentType", "IssuerCompany", "UnderlyingWKN", "UnderlyingISIN", "UnderlyingName", "UrlName", "IsETF",
		"TKExchangeId", "TKCurrencyId", "ImageUrl", "Text", "PublishDate", "PublishDateAsString" })
@SuppressWarnings("PMD.TooManyFields")
public class InstrumentType {

	/**
	 * Brese FFM BIAS der Wertpapieres
	 */
	@JsonProperty("Bias")
	private transient Integer bias;
	
	/**
	 * Kategorie
	 */
	@JsonProperty("Category")
	private transient String category;
	
	/**
	 * Bild URL
	 */
	@JsonProperty("ImageUrl")
	private transient Object imageUrl;
	
	/**
	 * Instrument-ID
	 */
	@JsonProperty("InstrumentID")
	private transient Integer instrumentID;
	
	/**
	 * Instrument-Typ
	 */
	@JsonProperty("InstrumentType")
	private transient String instrumentType; //NOPMD
	
	/**
	 * ETF
	 */
	@JsonProperty("IsETF")
	private transient Boolean isETF;
	
	/**
	 * ISIN
	 */
	@JsonProperty("ISIN")
	private transient String iSIN;
	
	/**
	 * Herausgeber
	 */
	@JsonProperty("IssuerCompany")
	private transient Object issuerCompany;
	
	/**
	 * Lakale-ID
	 */
	@JsonProperty("LocalIdentifier")
	private transient Object localIdentifier;
	
	/**
	 * Name
	 */
	@JsonProperty("Name")
	private transient String name;
	
	/**
	 * Erscheinungsdatum
	 */
	@JsonProperty("PublishDate")
	private transient String publishDate;
	
	/**
	 * Erscheinungsdatum als Text
	 */
	@JsonProperty("PublishDateAsString")
	private transient Object publishDateAsString;  //NOPMD
	
	/**
	 * Symbol (nicht Yahoo)
	 */
	@JsonProperty("Symbol")
	private transient Object symbol;
	
	/**
	 * Text???
	 */
	@JsonProperty("Text")
	private transient Object text;
	
	/**
	 * Whrungs-ID
	 */
	@JsonProperty("TKCurrencyId")
	private transient Integer tKCurrencyId;
	
	/**
	 * Wechselkurs-ID
	 */
	@JsonProperty("TKExchangeId")
	private transient Integer tKExchangeId;
	
	/**
	 * ISIN des zu grundeliegenden Papiers
	 */
	@JsonProperty("UnderlyingISIN")
	private transient Object underlyingISIN;
	
	/**
	 * Name des zu grundeliegenden Papiers
	 */
	@JsonProperty("UnderlyingName")
	private transient Object underlyingName;
	
	/**
	 * WKN  des zu grundeliegenden Papiers
	 */
	@JsonProperty("UnderlyingWKN")
	private transient Object underlyingWKN;
	
	/**
	 * URL Name
	 */
	@JsonProperty("UrlName")
	private transient String urlName;
	
	/**
	 * Valor ???
	 */
	@JsonProperty("Valor")
	private transient Integer valor;
	
	/**
	 * WKN
	 */
	@JsonProperty("WKN")
	private transient String wKN;

	/**
	 * Standardkonstruktor
	 */
	public InstrumentType() {
		// Absichtlich leer
	}
	
	/**
	 * Liefert das BIAS
	 * @return das BIAS
	 */
	@JsonProperty("Bias")
	public Integer getBias() {
		return bias;
	}

	/**
	 * Liefert die Kategorie
	 * @return die Kategorie
	 */
	@JsonProperty("Category")
	public String getCategory() {
		return category;
	}

	/**
	 * Liefert die Bild-URL
	 * @return die Bild-URL
	 */
	@JsonProperty("ImageUrl")
	public Object getImageUrl() {
		return imageUrl;
	}

	/**
	 * Liefert die Instrument-ID
	 * @return die Instrument-ID
	 */
	@JsonProperty("InstrumentID")
	public Integer getInstrumentID() {
		return instrumentID;
	}

	/**
	 * Liefert den Instrument-Typ
	 * @return den Instrument-Typ
	 */
	@JsonProperty("InstrumentType")
	public String getInstrumentType() {
		return instrumentType;
	}

	/**
	 * Ist EFT-Wert
	 * @return <i>true</i> wenn EFT
	 */
	@JsonProperty("IsETF")
	public Boolean getIsETF() {
		return isETF;
	}
	
/**
 * Liefert die ISIN
 * @return die ISIN
 */
	@JsonProperty("ISIN")
	public String getISIN() {
		return iSIN;
	}

	/**
	 * Liefert den Herausgeber
	 * @return den Herausgeber
	 */
	@JsonProperty("IssuerCompany")
	public Object getIssuerCompany() {
		return issuerCompany;
	}

	/**
	 * Liefert die lokale ID
	 * @return die lokale ID
	 */
	@JsonProperty("LocalIdentifier")
	public Object getLocalIdentifier() {
		return localIdentifier;
	}

	/**
	 * Liefert den Name
	 * @return den Name
	 */
	@JsonProperty("Name")
	public String getName() {
		return name;
	}

	/**
	 * Liefert das Erscheinungsdatum
	 * @return das Erscheinungsdatum
	 */
	@JsonProperty("PublishDate")
	public String getPublishDate() {
		return publishDate;
	}

	/**
	 * Liefert das Erscheinungsdatum als Text
	 * @return das Erscheinungsdatum als Text
	 */
	@JsonProperty("PublishDateAsString")
	public Object getPublishDateAsString() {
		return publishDateAsString;
	}

	/**
	 * Liefert das Symbol (nicht Yahoo-Symbol!!!)
	 * @return das Symbol (nicht Yahoo-Symbol!!!)
	 */
	@JsonProperty("Symbol")
	public Object getSymbol() {
		return symbol;
	}

	/**
	 * Liefert den Text (Beschreibung?)
	 * @return  den Text (Beschreibung?)
	 */
	@JsonProperty("Text")
	public Object getText() {
		return text;
	}

	/**
	 * Liefert die Whrungs-ID
	 * @return die Whrungs-ID
	 */
	@JsonProperty("TKCurrencyId")
	public Integer getTKCurrencyId() {
		return tKCurrencyId;
	}

	/**
	 * Liefert die Wechselkurs-ID
	 * @return die Wechselkurs-ID
	 */
	@JsonProperty("TKExchangeId")
	public Integer getTKExchangeId() {
		return tKExchangeId;
	}

	/**
	 * Liefert die ISIN des zugrundeliegenden Papiers
	 * @return die ISIN des zugrundeliegenden Papiers
	 */
	@JsonProperty("UnderlyingISIN")
	public Object getUnderlyingISIN() {
		return underlyingISIN;
	}

	/**
	 * Liefert den Namen des zugrundeliegenden Papiers
	 * @return den Namen des zugrundeliegenden Papiers
	 */
	@JsonProperty("UnderlyingName")
	public Object getUnderlyingName() {
		return underlyingName;
	}

	/**
	 * Liefert die WKN des zugrundeliegenden Papiers
	 * @return die WKN des zugrundeliegenden Papiers
	 */
	@JsonProperty("UnderlyingWKN")
	public Object getUnderlyingWKN() {
		return underlyingWKN;
	}

	/**
	 * Liefert die URL
	 * @return die URL
	 */
	@JsonProperty("UrlName")
	public String getUrlName() {
		return urlName;
	}

	/**
	 * Liefert das Valor
	 * @return das Valor
	 */
	@JsonProperty("Valor")
	public Integer getValor() {
		return valor;
	}

	/**
	 * Liefert die WKN
	 * @return die WKN
	 */
	@JsonProperty("WKN")
	public String getWKN() {
		return wKN;
	}

}
